import request from '@/utils/request'

// 初始化项目
export function initProject() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_项目名称_查询数据_按时间排序'
    }
  })
}
// 机床查询
export function searchmachine(check, num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_机床名称_查询数据',
      param: '项目流水号_check=' + check + '=int&项目流水号=' + num
    }
  })
}
// 分组查询
export function searchTeam(machineNumber) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: 'PDM_组件名称_查询数据',
      param: '机床流水号=' + machineNumber
    }
  })
}
// 采购合同查询
export function searchContract() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_库存管理_采购合同查询'
    }
  })
}
// 采购合同明细查询
export function searchContractDetail(contractnumber) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '采购管理_采购合同明细_查询数据',
      param: '采购合同流水号=' + contractnumber
    }
  })
}
// 直达件查询
export function searchDirectPart(pageCurrent, pageSize, project_check, project, machine_check, machine, group_check, group, contract_check, contract) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_直达件_零件查询',
      param: '项目流水号_check=' + project_check + '&项目流水号=' + project + '&机床流水号_check=' + machine_check + '&机床流水号=' + machine + '&组件流水号_check=' + group_check + '&组件流水号=' + group + '&合同流水号_check=' + contract_check + '&合同流水号=' + contract,
      Pagination: pageCurrent + '&' + pageSize
    }
  })
}
// 人员查询 需要在部门确定之后修改
export function searchPeople(data1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_人员查询_库存部门',
      param: '角色编号=' + data1
    }
  })
}
// 直达件增加
export function addDirectPart(data1, data2, data3, data4, data5, data6, data7, data8, data9, data10, data11, data12, data13, data14, data15) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_直达件_直达件增加',
      param: '实际到货数量=' + data1 + '&采购合同明细流水号=' + data2 + '&入库人员流水号=' + data3 + '&领用者=' + data4 + '&出库数量=' + data5 + '&组件零件流水号=' + data6 + '&组件零件基本件流水号=' + data7 + '&项目流水号=' + data8 + '&机床流水号=' + data9 + '&组件流水号=' + data10 + '&名称=' + data11 + '&备注=' + data12 + '&物料型号=' + data13 + '&物料规格=' + data14 + '&零件图号=' + data15
    }
  })
}
// 直达件记录查询
export function searchDirectRec(contractnumber) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '库存管理_直达件_直达件记录查询',
      param: '采购合同明细流水号=' + contractnumber
    }
  })
}
// 直达件记录修改
export function editDirectRec(data1, data2, data3, data4) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_直达件_直达件记录修改',
      param: '直达件流水号=' + data1 + '&到货数量=' + data2 + '&领用人员流水号=' + data3 + '&备注=' + data4
    }
  })
}
// 直达件记录删除
export function deleteDirectRec(data1) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '库存管理_直达件_直达件记录删除',
      param: '直达件流水号=' + data1
    }
  })
}
